# chosco 🏷️ [![ci](https://github.com/alice-biometrics/fuchicar/workflows/ci/badge.svg)](https://github.com/alice-biometrics/fuchicar/actions)

<img src="https://github.com/alice-biometrics/custom-emojis/blob/master/images/alice_header.png" width=auto>

Package on top of `ipywidgets` to label media resources on `Notebook` pages.


## Table of Contents
- [Installation :computer:](#installation-computer)
- [Development :construction_worker:](#development-construction_worker)
- [Testing :white_check_mark:](#testing-white_check_mark)
- [Contact :mailbox_with_mail:](#contact-mailbox_with_mail)


## Installation :computer:

```console
>> pip install chosco
```

## Development :construction_worker:

Use [lume :fire:](https://github.com/alice-biometrics/lume) to install dependencies:

Example:

```console
>> python3 -m venv venv
>> source venv/bin/activate
(venv) >> pip install lume
(venv) >> lume -install
```

## Testing :white_check_mark:

### Unit, Integration and Acceptance

```console
(venv) >> lume -test
```

## Notebooks

Run jupyter server:

```console
(venv) >> jupyter notebook
``` 

Go to dummy example [here](http://localhost:8888/notebooks/notebooks/dummy_annotation.ipynb)

## Contact :mailbox_with_mail:

support@alicebiometrics.com

